require 'spec_helper'

describe CreateFillOutRequest do
  let(:options) do
    {
      dossier_id: 'some_dossier_id',
      questionnaire_keys: ['qkey1', 'qkey2'],
      respondent_type: 'patient_version',
      callback_url: 'http://callback.url',
      reminders: [1000, 2000],
      open_from: Time.current,
      open_till: Time.current + 100_000
    }
  end
  let(:session)  { Sessions::BasicAuthSession.new }
  let(:response) { httparty_response({}) }
  before do
    allow(Sessions::BasicAuthSession).to receive(:new).and_return session
    allow(session).to receive(:post).and_return response
  end

  it 'does a post to the rom fill_out_requests api' do
    fill_out_request = {
      questionnaire_keys: options[:questionnaire_keys],
      respondent_type: options[:respondent_type],
      callback_url: options[:callback_url],
      reminders: options[:reminders],
      open_from: options[:open_from].to_i,
      open_till: options[:open_till].to_i
    }
    expect(session).to receive(:post).with("/dossiers/#{options[:dossier_id]}/fill_out_requests",
                                           fill_out_request: fill_out_request)
    CreateFillOutRequest.run!(options)
  end

  it 'returns a FillOutRequest' do
    response['id'] = 'fill_out_request_id'
    outcome = CreateFillOutRequest.run(options)
    expect(outcome.result.id).to eq('fill_out_request_id')
  end

  it 'accepts explicit nil values' do
    response['id'] = 'fill_out_request_id'
    options[:open_from] = nil
    options[:open_till] = nil
    options[:reminders] = nil
    expect(session).to receive(:post) do |_path, args|
      expect(args[:fill_out_request][:open_from]).to eq nil
      expect(args[:fill_out_request][:open_till]).to eq nil
      expect(args[:fill_out_request][:reminders]).to eq nil
      response
    end
    CreateFillOutRequest.run!(options)
  end
end
