require 'spec_helper'

describe CreateResponse do
  let(:session)  { Sessions::BasicAuthSession.new }
  let(:response) { httparty_response(questionnaire_name: 'Some Questionnaire') }
  before do
    allow(Sessions::BasicAuthSession).to receive(:new).and_return session
    allow(session).to receive(:post).and_return response
  end

  it 'does a post to the rom responses api' do
    filled_out_at = Time.current
    expect(session).to receive(:post).with '/dossiers/some_dossier_id/responses',
                                           questionnaire_key: 'some_questionnaire_key',
                                           answer_data: {some: 'answer_data'},
                                           filled_out_at: filled_out_at.to_i,
                                           respondent: 'patient'
    CreateResponse.run! dossier_id: 'some_dossier_id',
                        questionnaire_key: 'some_questionnaire_key',
                        answer_data: {some: 'answer_data'},
                        filled_out_at: filled_out_at,
                        respondent: 'patient'
  end

  it 'returns a response object' do
    response = CreateResponse.run! dossier_id: 'some_dossier_id',
                                   questionnaire_key: 'some_questionnaire_key',
                                   answer_data: {some: 'answer_data'},
                                   respondent: 'patient'
    expect(response).to be_a(Response)
    expect(response.questionnaire_name).to eq('Some Questionnaire')
  end
end
