require 'spec_helper'

describe ListDossierStats do
  let(:session)  { Fabricate :basic_auth_session }

  before do
    allow(BasicAuthSession).to receive(:new).and_return session
  end

  def assert_result(options)
    expect(subject.dossiers).to be_a(Hash)
    expect(subject.dossiers).to have_key(options[:key])
    expect(subject.dossiers['1']).to be_a(DossierStats)
    expect(subject.dossiers.size).to be options[:size]
  end

  describe 'with epd_ids provided' do
    let(:response) { {'foo' => {}, 'bar' => {}} }
    before do
      allow(session).to receive(:get).with('/stats', {epd_ids: ['foo', 'bar']}).and_return httparty_response(response)
    end

    subject { ListDossierStats.run! epd_ids: ['foo', 'bar'] }

    it 'performs a GET on the stats API with epd_ids' do
      expect(subject.dossiers.keys).to include('foo', 'bar')
    end
  end

  describe 'without epd_ids provided' do
    before do
      allow(session).to receive(:get).with('/stats', nil).and_return httparty_response(response)
    end

    subject { ListDossierStats.run! }

    context 'Single Dossier' do
      let(:response) { {"1" => {"responses" => {"total" => 10}, "invitations" => {"total" => 3}}} }

      it 'performs a GET on the stats API' do
        assert_result key: '1', size: 1
      end
    end

    context 'Multiple Dossiers' do
      let(:response) do
        {
          "1" => {"responses" => {"total" => 10}, "invitations" => {"total" => 3}},
          "2" => {"responses" => {"total" => 10}, "invitations" => {"total" => 3}},
          "3" => {"responses" => {"total" => 10}, "invitations" => {"total" => 3}}
        }
      end

      it 'performs a GET on the stats API' do
        assert_result key: '3', size: 3
      end
    end
  end
end
