require 'spec_helper'

describe ListNonResponses do
  let(:options) { {dossier_id: 'some_epd_id'} }
  let(:api_path) { "/dossiers/#{options[:dossier_id]}/non_responses" }
  let(:response) { httparty_response [{
    'id' => 1,
    'non_response_at' => "2017-02-08T11:02:41+01:00",
    'response_ids' => [1, 5, 9],
    'reason_group' => "Patiënt is wel benaderd voor de ROM meting, maar:",
    'reason_option' => "Patiënt retourneert meetinstrument niet.",
    'reason_code' => '04',
    'reason_other' => 'ik type, dus ik ben'}] }
  let(:session)  { Fabricate :basic_auth_session }
  before { allow(BasicAuthSession).to receive(:new).and_return session }

  it 'returns non_response objects' do
    allow(session).to receive(:get).with(api_path).and_return response
    non_responses = ListNonResponses.run(options).result

    expect(non_responses.first.id).to eq 1
    expect(non_responses.first.non_response_at).to eq Time.parse("2017-02-08T11:02:41+01:00")
    expect(non_responses.first.response_ids).to eq [1, 5, 9]
    expect(non_responses.first.reason_group).to eq "Patiënt is wel benaderd voor de ROM meting, maar:"
    expect(non_responses.first.reason_option).to eq "Patiënt retourneert meetinstrument niet."
    expect(non_responses.first.reason_code).to eq '04'
    expect(non_responses.first.reason_other).to eq 'ik type, dus ik ben'
  end
end
