require 'spec_helper'

describe ListResponses do
  let(:options)  { {dossier_id: '1'} }
  let(:api_path) { "/dossiers/#{options[:dossier_id]}/responses" }
  let(:response) { httparty_response [{"questionnaire_name" => "response_1"}, {"questionnaire_name" => "response_2"}] }
  let(:session)  { Fabricate :basic_auth_session }
  before { allow(BasicAuthSession).to receive(:new).and_return session }

  it 'performs a GET on the responses API' do
    expect(session).to receive(:get).with(api_path, {
      respondent_type: 'respondent_type',
      status: :status,
      questionnaire_keys: ['questionnaire_key'],
      completed_after: Time.new(2014, 1, 1),
      completed_before: Time.new(2014, 1, 31),
      protocol_subscription_id: 'protocol_subscription_id'
    }).and_return response
    ListResponses.run(dossier_id: options[:dossier_id],
                      respondent_type: 'respondent_type',
                      status: :status,
                      questionnaire_keys: ['questionnaire_key'],
                      completed_after: Time.new(2014, 1, 1),
                      completed_before: Time.new(2014, 1, 31),
                      protocol_subscription_id: 'protocol_subscription_id').result
  end

  it 'can get responses by id' do
    expect(session).to receive(:get).with(api_path, {response_ids: ['1', '5', '7']})
                                    .and_return response
    ListResponses.run!(dossier_id: options[:dossier_id],
                       response_ids: ['1', '5', '7'])
  end

  it 'returns an array of response objects' do
    allow(session).to receive(:get).with(api_path, {})
                                   .and_return response
    responses = ListResponses.run(options).result

    expect(responses).to be_a(Array)
    expect(responses.first).to be_a(Response)
    expect(responses.first.questionnaire_name).to eq('response_1')
  end
end
