require 'spec_helper'

describe ReportCalculations do
  let(:options)  { {dossier_id: '1', calculator: 'calc'} }
  let(:api_path) { "/dossiers/#{options[:dossier_id]}/report_calculations" }
  let(:response) { httparty_response('foo' => 'bar') }
  let(:session)  { Fabricate :basic_auth_session }

  before do
    allow(BasicAuthSession).to receive(:new).and_return session
    allow(session).to receive(:get).and_return response
  end

  subject { ReportCalculations.run!(options) }

  describe 'given a list of response_ids' do
    let(:options)  { {dossier_id: '1', response_ids: ['1', '2'], calculator: 'calc'} }

    it 'returns the response' do
      expect(subject).to eq('foo' => 'bar')
    end

    it 'calls the right url' do
      expect(session).to receive(:get).with(api_path, options.slice(:calculator, :response_ids))
      subject
    end
  end

  describe 'given a list of questionnaire_keys' do
    let(:filters)  { {questionnaire_keys: ['q1', 'q2'],
                      completed_after: Time.current - 100_000, completed_before: Time.current} }
    let(:options)  { {dossier_id: '1', calculator: 'test'}.merge(filters) }

    it 'calls the right url' do
      filter_hash = {
        questionnaire_keys: filters[:questionnaire_keys],
        completed_after: filters[:completed_after].to_i,
        completed_before: filters[:completed_before].to_i
      }
      expect(session).to receive(:get).with(api_path, {calculator: 'test', filters: filter_hash})
      subject
    end
  end

  describe 'given neither response_ids or questionnaire_keys' do
    let(:options)  { {dossier_id: '1', calculator: 'calc'} }

    it 'should add an attr missing error' do
      expect { subject }.to raise_error(ActiveInteraction::InvalidInteractionError)
    end
  end
end
