require 'spec_helper'

describe StartFillOutSession do
  let(:options)  do
    {
      dossier_id: 'some_dossier_id',
      questionnaire_keys: ['some_key'],
      return_to: '/some/return/url',
      progress_url: '/some/progress/page',
      stylesheet: 'https://example.org/stylesheet.css'
    }
  end
  let(:session)  { Sessions::BasicAuthSession.new }
  let(:response) { httparty_response 'fill_out_url' => 'some_fill_out_url' }
  before do
    allow(Sessions::BasicAuthSession).to receive(:new).and_return session
    allow(session).to receive(:post).and_return response
  end

  it 'does a post to the rom fill_out_sessions api' do
    options[:response_ids] = [1, 2]
    expect(session).to receive(:post).with("/dossiers/#{options[:dossier_id]}/fill_out_sessions",
                                           questionnaire_keys: options[:questionnaire_keys],
                                           response_ids: options[:response_ids],
                                           return_to: options[:return_to],
                                           progress_url: options[:progress_url],
                                           stylesheet: options[:stylesheet])
    StartFillOutSession.run!(options)
  end

  it 'returns the received fill_out url' do
    outcome = StartFillOutSession.run(options)
    expect(outcome.result).to eq('some_fill_out_url')
  end

  it 'validates the presence of questionnaire keys' do
    options[:questionnaire_keys] = []
    outcome = StartFillOutSession.run(options)
    expect(outcome).not_to be_valid
    expect(outcome.errors.full_messages).to include("Questionnaire keys can't be blank")
  end

  it 'does not validate the presence of questionnaire keys when answer_ids are given' do
    options[:questionnaire_keys] = []
    options[:response_ids] = [1, 2]
    outcome = StartFillOutSession.run(options)
    expect(outcome).to be_valid
  end
end
