require 'spec_helper'

describe StartProtocolSubscription do
  let(:options)  { {dossier_id: 'some_dossier_id', protocol_key: 'some_key', protocol_id: nil,
                    respondent_id: 123, flags: {some_flag: true}, textvars: {some_var: 'string'}} }
  let(:session)  { Sessions::BasicAuthSession.new }
  let(:response) { httparty_response({}) }
  before do
    allow(Sessions::BasicAuthSession).to receive(:new).and_return session
    allow(session).to receive(:post).and_return response
  end

  it 'does a post to the rom protocol_subscription api' do
    expect(session).to receive(:post).with("/dossiers/#{options[:dossier_id]}/protocol_subscriptions", {
      protocol_key: options[:protocol_key],
      protocol_id: options[:protocol_id],
      respondent_id: options[:respondent_id],
      flags: {"some_flag" => true},
      textvars: {"some_var" => 'string'}
    })
    StartProtocolSubscription.run!(options)
  end

  it 'passes in the start_at option when provided' do
    start_at = Time.current
    expect(session).to receive(:post).with("/dossiers/#{options[:dossier_id]}/protocol_subscriptions", {
      protocol_key: options[:protocol_key],
      protocol_id: options[:protocol_id],
      respondent_id: options[:respondent_id],
      start_at: start_at.to_i,
      flags: {"some_flag" => true},
      textvars: {"some_var" => 'string'}
    })
    StartProtocolSubscription.run!(options.merge start_at: start_at)
  end

  it 'returns the response' do
    subscription = StartProtocolSubscription.run!(options)
    expect(subscription).to be_a(Models::ProtocolSubscription)
  end
end
