require 'spec_helper'

describe UpdateResponse do
  let(:session)  { Sessions::BasicAuthSession.new }
  let(:response) { httparty_response(questionnaire_name: 'Some Questionnaire') }
  let(:started_at) { 10.minutes.ago}
  before do
    allow(Sessions::BasicAuthSession).to receive(:new).and_return session
    allow(session).to receive(:patch).and_return response
  end

  it 'does a post to the rom responses api' do
    filled_out_at = Time.current
    expect(session).to receive(:patch).with '/dossiers/some_dossier_id/responses/230',
                                            questionnaire_key: 'some_questionnaire_key',
                                            answer_data: {some: 'answer_data'},
                                            filled_out_at: filled_out_at.to_i,
                                            started_at: started_at.to_i
    UpdateResponse.run! dossier_id: 'some_dossier_id',
                        questionnaire_key: 'some_questionnaire_key',
                        external_id: "230",
                        answer_data: {some: 'answer_data'},
                        filled_out_at: filled_out_at,
                        started_at: started_at
  end

  it 'returns a response object' do
    response = UpdateResponse.run! dossier_id: 'some_dossier_id',
                                   questionnaire_key: 'some_questionnaire_key',
                                   answer_data: {some: 'answer_data'},
                                   respondent: 'patient',
                                   started_at: started_at,
                                   external_id: "230"
    expect(response).to be_a(Response)
    expect(response.questionnaire_name).to eq('Some Questionnaire')
  end
end
